@@ -160,7 +160,7 @@ class MaskFile:
             comment = []
             i = mask_lines[0] - 2
             while i >= 0 and (line := lines[i].rstrip()):
-                if not line.startswith('# '):
+                if not line.startswith('# ') and line != '#':
                     mask.error(f'invalid mask entry header, lineno {i + 1}: {line!r}')
                 comment.append(line[2:])
                 i -= 1
@@ -189,14 +189,19 @@ class MaskFile:
         return ''.join(self.header) + '\n\n'.join(map(str, self.masks))
 
 
-def get_comment(bugs):
+def get_comment(bugs, rites: int):
     """Spawn editor to get mask comment."""
     tmp = tempfile.NamedTemporaryFile(mode='w')
+    summary = []
+    if rites:
+        summary.append(f'Removal: {datetime.now(timezone.utc) + timedelta(days=rites):%Y-%m-%d}.')
     if bugs:
         # Bug(s) #A, #B, #C
         bug_list = ", ".join(f'#{b}' for b in bugs)
         s = pluralism(bugs)
-        tmp.write(f'\nBug{s} {bug_list}')
+        summary.append(f'Bug{s} {bug_list}.')
+    if summary := '  '.join(summary):
+        tmp.write(f'\n{summary}')
     tmp.write(textwrap.dedent("""
 
         # Please enter the mask message. Lines starting with '#' will be ignored.
@@ -268,15 +273,10 @@ def _mask(options, out, err):
         'author': author,
         'email': email,
         'date': today.strftime('%Y-%m-%d'),
-        'comment': get_comment(options.bugs),
+        'comment': get_comment(options.bugs, options.rites),
         'atoms': options.atoms,
     }
 
-    if options.rites:
-        removal_date = today + timedelta(days=options.rites)
-        removal = removal_date.strftime('%Y-%m-%d')
-        mask_args['comment'].append(f'Removal: {removal}')
-
     m = Mask(**mask_args)
     mask_file.add(m)
     mask_file.write()
